Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorCampbell Barton <ideasman42@gmail.com>2019-03-22 05:23:07 +0300
committerCampbell Barton <ideasman42@gmail.com>2019-03-22 07:43:23 +0300
commit00f7dcd5be1fb32a65b5abccc09db6fec775c3cf (patch)
tree5fd5a1b1762f1f3cd56d50cc7c9712b0753521ac
parent78ce2063d3dd490fc2450e4e12d9680104e25924 (diff)
DRW: show clipping border for solid mode
Solid + xray is still not supported.
-rw-r--r--source/blender/draw/engines/workbench/workbench_forward.c5
1 files changed, 3 insertions, 2 deletions
diff --git a/source/blender/draw/engines/workbench/workbench_forward.c b/source/blender/draw/engines/workbench/workbench_forward.c
index a31eb4963b8..89a47cb0dfe 100644
--- a/source/blender/draw/engines/workbench/workbench_forward.c
+++ b/source/blender/draw/engines/workbench/workbench_forward.c
@@ -370,8 +370,9 @@ void workbench_forward_engine_init(WORKBENCH_Data *vedata)
DRW_shgroup_call_add(grp, DRW_cache_fullscreen_quad_get(), NULL);
}
- /* TODO(campbell): displays but masks geometry, only use with wire for now. */
- if ((wpd->shading.type == OB_WIRE) &&
+ /* TODO(campbell): displays but masks geometry,
+ * only use with wire or solid-without-xray for now. */
+ if (((wpd->shading.type != OB_WIRE && XRAY_FLAG(wpd) == 0)) &&
(draw_ctx->rv3d && (draw_ctx->rv3d->rflag & RV3D_CLIPPING) && draw_ctx->rv3d->clipbb))
{
psl->background_pass = DRW_pass_create(